@@ -1,6 +1,5 @@
 import json
 from embed.common import APIResponse
-from embed.errors import ValidationError
 
 
 class Account(APIResponse):
@@ -16,9 +15,7 @@ class Account(APIResponse):
 
     def create_account(self, **kwargs):
         required = ["first_name", "last_name", "email"]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
         if "idempotency_key" in kwargs.keys():
             self._headers.update(
                 {"Embed-Idempotency-Key": str(kwargs.pop("idempotency_key"))}
@@ -30,9 +27,7 @@ class Account(APIResponse):
         return self.get_essential_details(method, url, payload)
 
     def list_accounts(self, **kwargs):
-        query_path = "&".join(
-            "{}={}".format(key, value) for key, value in kwargs.items()
-        )
+        query_path = self._format_query(kwargs)
         method = "GET"
         url = self.base_url + "accounts"
         if query_path:
@@ -53,6 +48,23 @@ class Account(APIResponse):
         url = self.base_url + f"accounts/{account_id}/portfolio"
         return self.get_essential_details(method, url)
 
+    def get_portfolio_performance(self, **kwargs):
+        """
+        Get the performance of a portfolio
+        """
+        required = ["account_id", "currency"]
+        # optional = ["start_date", "end_date"]
+
+        self._validate_kwargs(required, kwargs)
+        query_path = self._format_query(kwargs)
+        method = "GET"
+        url = (
+            self.base_url + f"accounts/{kwargs.get('account_id')}/portfolio/performance"
+        )
+        if query_path:
+            url = f"{url}?{query_path}"
+        return self.get_essential_details(method, url)
+
     def update_address(self, **kwargs):
         """
         Update the address of an account
@@ -67,9 +79,7 @@ class Account(APIResponse):
             "state",
             "country",
         ]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
 
         method = "POST"
         account_id = kwargs.get("account_id")
@@ -92,9 +102,7 @@ class Account(APIResponse):
             "relationship",
             "gender",
         ]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
 
         method = "POST"
         account_id = kwargs.get("account_id")
@@ -109,9 +117,7 @@ class Account(APIResponse):
         Gender options: M or F
         """
         required = ["account_id"]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
 
         method = "POST"
         account_id = kwargs.get("account_id")
@@ -123,9 +129,7 @@ class Account(APIResponse):
     def update_identity(self, **kwargs):
 
         required = ["account_id", "identity_type", "identity_value"]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
 
         method = "POST"
         account_id = kwargs.get("account_id")
@@ -133,3 +137,49 @@ class Account(APIResponse):
 
         payload = json.dumps(kwargs)
         return self.get_essential_details(method, url, payload)
+
+    def add_bank_account(self, **kwargs):
+        """
+        Add a bank account to profile.
+        The bank_code can be gotten from calling get_banks() of Misc
+        """
+        required = ["account_id", "bank_code", "account_number"]
+        self._validate_kwargs(required, kwargs)
+
+        method = "POST"
+        account_id = kwargs.get("account_id")
+        url = self.base_url + f"accounts/{account_id}/bank"
+
+        payload = json.dumps(kwargs)
+        return self.get_essential_details(method, url, payload)
+
+    def get_risk_profile_questions(self):
+        """
+        Get questions to used to determine risk profile of user
+        """
+        method = "GET"
+        url = self.base_url + "accounts/risk-profile-questions"
+        return self.get_essential_details(method, url)
+
+    def update_risk_profile(self, **kwargs):
+        """
+        Post answers to risk profile questions and get risk score
+        """
+        required = ["account_id", "q1", "q2", "q3", "q4", "q5", "q6"]
+        self._validate_kwargs(required, kwargs)
+
+        method = "POST"
+        account_id = kwargs.get("account_id")
+        url = self.base_url + f"accounts/{account_id}/risk-profile"
+
+        kwargs = {int(k.replace("q", "")): kwargs.pop(k) for k in required[1:]}
+        payload = json.dumps(kwargs)
+        return self.get_essential_details(method, url, payload)
+
+    def get_risk_profile(self, account_id):
+        """
+        Get a customer's risk profile
+        """
+        method = "GET"
+        url = self.base_url + f"accounts/{account_id}/risk-profile"
+        return self.get_essential_details(method, url)
