@@ -1,6 +1,5 @@
 import json
 from embed.common import APIResponse
-from embed.errors import ValidationError
 
 
 class Investment(APIResponse):
@@ -15,9 +14,11 @@ class Investment(APIResponse):
         self._headers.update({"Authorization": f"Bearer {self.token}"})
 
     def list_investments(self, **kwargs):
-        query_path = "&".join(
-            "{}={}".format(key, value) for key, value in kwargs.items()
-        )
+        """
+        Gets a list of investments. Filter result by asset-type by supplying
+        the asset-type code as `asset_type` as kwarg
+        """
+        query_path = "&".join(f"{k}={v}" for k, v in kwargs.items())
         method = "GET"
         url = self.base_url + "investments"
         if query_path:
@@ -31,9 +32,7 @@ class Investment(APIResponse):
 
     def create_investment(self, **kwargs):
         required = ["account_id", "asset_code"]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
 
         if "idempotency_key" in kwargs.keys():
             self._headers.update(
@@ -46,9 +45,7 @@ class Investment(APIResponse):
 
     def liquidate_investment(self, **kwargs):
         required = ["investment_id", "units"]
-        for key in required:
-            if key not in kwargs.keys():
-                raise ValidationError(f"{key} is required.")
+        self._validate_kwargs(required, kwargs)
 
         if "idempotency_key" in kwargs.keys():
             self._headers.update(
@@ -61,3 +58,27 @@ class Investment(APIResponse):
 
         payload = json.dumps(kwargs)
         return self.get_essential_details(method, url, payload)
+
+    def get_investment_holdings(self, investment_id):
+        """
+        For Indexes
+        """
+        method = "GET"
+        url = self.base_url + f"investments/{investment_id}/holdings"
+        return self.get_essential_details(method, url)
+
+    def get_investment_performance(self, investment_id):
+        """
+        Get investment performance timeseries
+        """
+        method = "GET"
+        url = self.base_url + f"investments/{investment_id}/performance"
+        return self.get_essential_details(method, url)
+
+    def get_investment_returns(self, investment_id):
+        """
+        Get investment performance timeseries
+        """
+        method = "GET"
+        url = self.base_url + f"investments/{investment_id}/returns"
+        return self.get_essential_details(method, url)
